@@ -439,10 +439,7 @@ class ADBServerSync(object):
 
         with _acquire(self._adb_lock):
             _LOGGER.debug("Taking screencap from %s:%d via ADB server %s:%d", self.host, self.port, self.adb_server_ip, self.adb_server_port)
-            try:
-                return self._adb_device.screencap()
-            except IndexError:
-                return None
+            return self._adb_device.screencap()
 
     def shell(self, cmd):
         """Send an ADB command using an ADB server.
