@@ -55,6 +55,9 @@ CMD_RUNNING_APPS_ANDROIDTV = "ps -A | grep u0_a"
 #: Get the running apps for a Fire TV device
 CMD_RUNNING_APPS_FIRETV = "ps | grep u0_a"
 
+#: Get installed apps
+CMD_INSTALLED_APPS = "pm list packages"
+
 #: Determine if the device is on
 CMD_SCREEN_ON = "(dumpsys power | grep 'Display Power' | grep -q 'state=ON' || dumpsys power | grep -q 'mScreenOn=true')"
 
